@@ -19,12 +19,12 @@ package org.apache.wicket.protocol.http;
 import java.util.List;
 import java.util.Map;
 
-import org.apache.commons.fileupload.FileItem;
+import org.apache.commons.fileupload2.core.FileItem;
 
 
 /**
  * An interface providing access to multipart content uploads of a WebRequest
- * 
+ *
  * @author Ate Douma
  */
 public interface IMultipartWebRequest
@@ -32,14 +32,14 @@ public interface IMultipartWebRequest
 	/**
 	 * @return Returns the files.
 	 */
-	public Map<String, List<FileItem>> getFiles();
+	Map<String, List<FileItem>> getFiles();
 
 	/**
 	 * Gets the files that were uploaded using the given field name.
-	 * 
+	 *
 	 * @param fieldName
 	 *            the field name that was used for the upload
 	 * @return the uploads with the given field name
 	 */
-	public List<FileItem> getFile(final String fieldName);
+	List<FileItem> getFile(final String fieldName);
 }
